==> ae_sys_data-0.0.5.tar.gz: ae_sys_data-0.0.5/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE AE ROOT PACKAGE. ANY CHANGES SHOULD BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# sys_data Portion Of ae Namespace Package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_sys_data/master?logo=python)](
    https://gitlab.com/ae-group/ae_sys_data)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_sys_data)](https://pypi.org/project/ae-sys_data/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_sys_data/coverage.svg)](
    https://ae-group.gitlab.io/ae_sys_data/coverage/ae_sys_data_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_sys_data/mypy.svg)](
    https://ae-group.gitlab.io/ae_sys_data/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_sys_data/pylint.svg)](https://ae-group.gitlab.io/ae_sys_data/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_sys_data)](https://pypi.org/project/ae-sys_data/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_sys_data)](https://pypi.org/project/ae-sys_data/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_sys_data)](https://pypi.org/project/ae-sys_data/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_sys_data)](https://pypi.org/project/ae-sys_data/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_sys_data)](https://libraries.io/pypi/ae-sys_data)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_sys_data)](https://pypi.org/project/ae-sys_data/#files)


## Installation

Execute the following command for to use the ae.sys_data module in your
application. It will install ae.sys_data into your python (virtual) environment:
 
```shell script
pip install ae-sys_data
```

If you instead want to contribute to this portion then first fork
[the ae-sys_data repository at GitLab](https://gitlab.com/ae-group/ae_sys_data "ae.sys_data code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_sys_data):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## Namespace Portion Documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.sys_data.html#module-ae.sys_data
"ae_sys_data documentation").

<!-- initial upload of ae_sys_data module version 0.0.1.
-->

==> ae_sys_data-0.0.6.tar.gz: ae_sys_data-0.0.6/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE AE ROOT PACKAGE. ANY CHANGES SHOULD BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# sys_data Portion Of ae Namespace Package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_sys_data/master?logo=python)](
    https://gitlab.com/ae-group/ae_sys_data)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_sys_data)](
    https://pypi.org/project/ae-sys_data/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_sys_data/coverage.svg)](
    https://ae-group.gitlab.io/ae_sys_data/coverage/ae_sys_data_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_sys_data/mypy.svg)](
    https://ae-group.gitlab.io/ae_sys_data/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_sys_data/pylint.svg)](
    https://ae-group.gitlab.io/ae_sys_data/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_sys_data)](
    https://pypi.org/project/ae-sys_data/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_sys_data)](
    https://pypi.org/project/ae-sys_data/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_sys_data)](
    https://pypi.org/project/ae-sys_data/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_sys_data)](
    https://pypi.org/project/ae-sys_data/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_sys_data)](
    https://libraries.io/pypi/ae-sys_data)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_sys_data)](
    https://pypi.org/project/ae-sys_data/#files)


## Installation

Execute the following command for to use the ae.sys_data module in your
application. It will install ae.sys_data into your python (virtual) environment:
 
```shell script
pip install ae-sys_data
```

If you instead want to contribute to this portion then first fork
[the ae-sys_data repository at GitLab](https://gitlab.com/ae-group/ae_sys_data "ae.sys_data code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_sys_data):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## Namespace Portion Documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.sys_data.html#module-ae.sys_data
"ae_sys_data documentation").

<!-- Common files version 0.0.33 deployed (with 0.0.33)
     to the ae_sys_data module version 0.0.6.
-->
